@@ -144,7 +144,8 @@ DEFAULT_PAGINATION_CHOICES = [
 DEFAULT_PAGE_LAYOUT = "bread.layout.default_page_layout"
 
 BREAD_PUBLIC_FILES_PREFIX = (
-    "public/"  # request starting with this path will not require login
+    "public"  # request starting with this path will not require login
 )
 
 AJAX_URLPARAMETER = "asajax"
+HIDEMENUS_URLPARAMETER = "hidemenus"
