@@ -4,7 +4,11 @@ INSTALLED_APPS = BREAD_DEPENDENCIES + [  # noqa
     "django.contrib.admin",
     "bread.contrib.reports",
     "bread.contrib.triggers",
+    "bread.contrib.document_templates",
+    "bread.contrib.languages",
+    "bread.contrib.publicurls",
 ]
+
 SECRET_KEY = "test"  # nosec because this is only used to run tests
 ROOT_URLCONF = "bread.tests.urls"
 DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}
